@@ -22,7 +22,7 @@ import com.google.common.collect.ImmutableSortedSet;
 import com.google.errorprone.annotations.CanIgnoreReturnValue;
 import java.nio.file.attribute.FileTime;
 import java.util.Iterator;
-import org.checkerframework.checker.nullness.qual.Nullable;
+import org.jspecify.annotations.Nullable;
 
 /**
  * A table of {@linkplain DirectoryEntry directory entries}.
@@ -148,7 +148,7 @@ final class Directory extends File implements Iterable<DirectoryEntry> {
    */
   public ImmutableSortedSet<Name> snapshot() {
     ImmutableSortedSet.Builder<Name> builder =
-        new ImmutableSortedSet.Builder<>(Name.displayOrdering());
+        new ImmutableSortedSet.Builder<>(Name.displayComparator());
 
     for (DirectoryEntry entry : this) {
       if (!isReserved(entry.name())) {
