@@ -27,7 +27,7 @@ import java.nio.file.NoSuchFileException;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
-import org.checkerframework.checker.nullness.qual.Nullable;
+import org.jspecify.annotations.Nullable;
 
 /**
  * The tree of directories and files for the file system. Contains the file system root directories
@@ -51,7 +51,7 @@ final class FileTree {
 
   /** Creates a new file tree with the given root directories. */
   FileTree(Map<Name, Directory> roots) {
-    this.roots = ImmutableSortedMap.copyOf(roots, Name.canonicalOrdering());
+    this.roots = ImmutableSortedMap.copyOf(roots, Name.canonicalComparator());
   }
 
   /** Returns the names of the root directories in this tree. */
