@@ -22,6 +22,7 @@ import static java.nio.file.StandardOpenOption.APPEND;
 import static java.nio.file.StandardOpenOption.READ;
 import static java.nio.file.StandardOpenOption.WRITE;
 
+import com.google.errorprone.annotations.CanIgnoreReturnValue;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.nio.MappedByteBuffer;
@@ -44,9 +45,6 @@ import java.util.Set;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.atomic.AtomicBoolean;
 
-import javax.annotation.Nullable;
-import javax.annotation.concurrent.GuardedBy;
-
 /**
  * A {@link FileChannel} implementation that reads and writes to a {@link RegularFile} object. The
  * read and write methods and other methods that read or change the position of the channel are
@@ -161,7 +159,7 @@ final class JimfsFileChannel extends FileChannel {
           if (read != -1) {
             position += read;
           }
-          file.updateAccessTime();
+          file.setLastAccessTime(fileSystemState.now());
           completed = true;
         } finally {
           file.readLock().unlock();
@@ -198,7 +196,7 @@ final class JimfsFileChannel extends FileChannel {
           if (read != -1) {
             position += read;
           }
-          file.updateAccessTime();
+          file.setLastAccessTime(fileSystemState.now());
           completed = true;
         } finally {
           file.readLock().unlock();
@@ -213,6 +211,38 @@ final class JimfsFileChannel extends FileChannel {
     return read;
   }
 
+  @Override
+  public int read(ByteBuffer dst, long position) throws IOException {
+    checkNotNull(dst);
+    Util.checkNotNegative(position, "position");
+    checkOpen();
+    checkReadable();
+
+    int read = 0; // will definitely either be assigned or an exception will be thrown
+
+    // no need to synchronize here; this method does not make use of the channel's position
+    boolean completed = false;
+    try {
+      if (!beginBlocking()) {
+        return 0; // AsynchronousCloseException will be thrown
+      }
+      file.readLock().lockInterruptibly();
+      try {
+        read = file.read(position, dst);
+        file.setLastAccessTime(fileSystemState.now());
+        completed = true;
+      } finally {
+        file.readLock().unlock();
+      }
+    } catch (InterruptedException e) {
+      Thread.currentThread().interrupt();
+    } finally {
+      endBlocking(completed);
+    }
+
+    return read;
+  }
+
   @Override
   public int write(ByteBuffer src) throws IOException {
     checkNotNull(src);
@@ -234,7 +264,7 @@ final class JimfsFileChannel extends FileChannel {
           }
           written = file.write(position, src);
           position += written;
-          file.updateModifiedTime();
+          file.setLastModifiedTime(fileSystemState.now());
           completed = true;
         } finally {
           file.writeLock().unlock();
@@ -272,7 +302,66 @@ final class JimfsFileChannel extends FileChannel {
           }
           written = file.write(position, buffers);
           position += written;
-          file.updateModifiedTime();
+          file.setLastModifiedTime(fileSystemState.now());
+          completed = true;
+        } finally {
+          file.writeLock().unlock();
+        }
+      } catch (InterruptedException e) {
+        Thread.currentThread().interrupt();
+      } finally {
+        endBlocking(completed);
+      }
+    }
+
+    return written;
+  }
+
+  @Override
+  public int write(ByteBuffer src, long position) throws IOException {
+    checkNotNull(src);
+    Util.checkNotNegative(position, "position");
+    checkOpen();
+    checkWritable();
+
+    int written = 0; // will definitely either be assigned or an exception will be thrown
+
+    if (append) {
+      // synchronize because appending does update the channel's position
+      synchronized (this) {
+        boolean completed = false;
+        try {
+          if (!beginBlocking()) {
+            return 0; // AsynchronousCloseException will be thrown
+          }
+
+          file.writeLock().lockInterruptibly();
+          try {
+            position = file.sizeWithoutLocking();
+            written = file.write(position, src);
+            this.position = position + written;
+            file.setLastModifiedTime(fileSystemState.now());
+            completed = true;
+          } finally {
+            file.writeLock().unlock();
+          }
+        } catch (InterruptedException e) {
+          Thread.currentThread().interrupt();
+        } finally {
+          endBlocking(completed);
+        }
+      }
+    } else {
+      // don't synchronize because the channel's position is not involved
+      boolean completed = false;
+      try {
+        if (!beginBlocking()) {
+          return 0; // AsynchronousCloseException will be thrown
+        }
+        file.writeLock().lockInterruptibly();
+        try {
+          written = file.write(position, src);
+          file.setLastModifiedTime(fileSystemState.now());
           completed = true;
         } finally {
           file.writeLock().unlock();
@@ -311,6 +400,7 @@ final class JimfsFileChannel extends FileChannel {
   }
 
   @Override
+  @CanIgnoreReturnValue
   public FileChannel position(long newPosition) throws IOException {
     Util.checkNotNegative(newPosition, "newPosition");
     checkOpen();
@@ -360,6 +450,7 @@ final class JimfsFileChannel extends FileChannel {
   }
 
   @Override
+  @CanIgnoreReturnValue
   public FileChannel truncate(long size) throws IOException {
     Util.checkNotNegative(size, "size");
     checkOpen();
@@ -377,7 +468,7 @@ final class JimfsFileChannel extends FileChannel {
           if (position > size) {
             position = size;
           }
-          file.updateModifiedTime();
+          file.setLastModifiedTime(fileSystemState.now());
           completed = true;
         } finally {
           file.writeLock().unlock();
@@ -426,7 +517,7 @@ final class JimfsFileChannel extends FileChannel {
       file.readLock().lockInterruptibly();
       try {
         transferred = file.transferTo(position, count, target);
-        file.updateAccessTime();
+        file.setLastAccessTime(fileSystemState.now());
         completed = true;
       } finally {
         file.readLock().unlock();
@@ -464,7 +555,7 @@ final class JimfsFileChannel extends FileChannel {
             position = file.sizeWithoutLocking();
             transferred = file.transferFrom(src, position, count);
             this.position = position + transferred;
-            file.updateModifiedTime();
+            file.setLastModifiedTime(fileSystemState.now());
             completed = true;
           } finally {
             file.writeLock().unlock();
@@ -485,7 +576,7 @@ final class JimfsFileChannel extends FileChannel {
         file.writeLock().lockInterruptibly();
         try {
           transferred = file.transferFrom(src, position, count);
-          file.updateModifiedTime();
+          file.setLastModifiedTime(fileSystemState.now());
           completed = true;
         } finally {
           file.writeLock().unlock();
@@ -500,97 +591,6 @@ final class JimfsFileChannel extends FileChannel {
     return transferred;
   }
 
-  @Override
-  public int read(ByteBuffer dst, long position) throws IOException {
-    checkNotNull(dst);
-    Util.checkNotNegative(position, "position");
-    checkOpen();
-    checkReadable();
-
-    int read = 0; // will definitely either be assigned or an exception will be thrown
-
-    // no need to synchronize here; this method does not make use of the channel's position
-    boolean completed = false;
-    try {
-      if (!beginBlocking()) {
-        return 0; // AsynchronousCloseException will be thrown
-      }
-      file.readLock().lockInterruptibly();
-      try {
-        read = file.read(position, dst);
-        file.updateAccessTime();
-        completed = true;
-      } finally {
-        file.readLock().unlock();
-      }
-    } catch (InterruptedException e) {
-      Thread.currentThread().interrupt();
-    } finally {
-      endBlocking(completed);
-    }
-
-    return read;
-  }
-
-  @Override
-  public int write(ByteBuffer src, long position) throws IOException {
-    checkNotNull(src);
-    Util.checkNotNegative(position, "position");
-    checkOpen();
-    checkWritable();
-
-    int written = 0; // will definitely either be assigned or an exception will be thrown
-
-    if (append) {
-      // synchronize because appending does update the channel's position
-      synchronized (this) {
-        boolean completed = false;
-        try {
-          if (!beginBlocking()) {
-            return 0; // AsynchronousCloseException will be thrown
-          }
-
-          file.writeLock().lockInterruptibly();
-          try {
-            position = file.sizeWithoutLocking();
-            written = file.write(position, src);
-            this.position = position + written;
-            file.updateModifiedTime();
-            completed = true;
-          } finally {
-            file.writeLock().unlock();
-          }
-        } catch (InterruptedException e) {
-          Thread.currentThread().interrupt();
-        } finally {
-          endBlocking(completed);
-        }
-      }
-    } else {
-      // don't synchronize because the channel's position is not involved
-      boolean completed = false;
-      try {
-        if (!beginBlocking()) {
-          return 0; // AsynchronousCloseException will be thrown
-        }
-        file.writeLock().lockInterruptibly();
-        try {
-          written = file.write(position, src);
-          file.updateModifiedTime();
-          completed = true;
-        } finally {
-          file.writeLock().unlock();
-        }
-      } catch (InterruptedException e) {
-        Thread.currentThread().interrupt();
-      } finally {
-        endBlocking(completed);
-      }
-    }
-
-    return written;
-  }
-
   @Override
   public MappedByteBuffer map(MapMode mode, long position, long size) throws IOException {
     // would like this to pretend to work, but can't create an implementation of MappedByteBuffer
@@ -652,9 +652,7 @@ final class JimfsFileChannel extends FileChannel {
     }
   }
 
-  /**
-   * A file lock that does nothing, since only one JVM process has access to this file system.
-   */
+  /** A file lock that does nothing, since only one JVM process has access to this file system. */
   static final class FakeFileLock extends FileLock {
 
     private final AtomicBoolean valid = new AtomicBoolean(true);
