@@ -17,18 +17,15 @@
 package com.google.common.jimfs;
 
 import java.nio.file.attribute.FileTime;
+import java.time.Instant;
 
 /** Implementation of of {@link FileTimeSource} that gets the current time from the system. */
 enum SystemFileTimeSource implements FileTimeSource {
   INSTANCE;
 
-  // If/when Jimfs requires Java 8 this should use the FileTime factory that takes an Instant as
-  // that has the potential to be more precise. At that point, we should make a similar change to
-  // FakeFileTimeSource.
-
   @Override
   public FileTime now() {
-    return FileTime.fromMillis(System.currentTimeMillis());
+    return FileTime.from(Instant.now());
   }
 
   @Override
