@@ -16,10 +16,12 @@
 
 /**
  * Package containing the Jimfs file system API and implementation. Most users should only need to
- * use the {@link com.google.common.jimfs.Jimfs Jimfs} and
- * {@link com.google.common.jimfs.Configuration Configuration} classes.
+ * use the {@link com.google.common.jimfs.Jimfs Jimfs} and {@link
+ * com.google.common.jimfs.Configuration Configuration} classes.
  */
+@CheckReturnValue
 @ParametersAreNonnullByDefault
 package com.google.common.jimfs;
 
+import com.google.errorprone.annotations.CheckReturnValue;
 import javax.annotation.ParametersAreNonnullByDefault;
