@@ -44,9 +44,9 @@ import static org.junit.Assert.fail;
 
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableSet;
+import com.google.common.collect.ImmutableSortedSet;
 import com.google.common.collect.Iterables;
 import com.google.common.collect.Iterators;
-import com.google.common.collect.Ordering;
 import com.google.common.io.ByteStreams;
 import com.google.common.io.CharStreams;
 import com.google.common.primitives.Bytes;
@@ -87,7 +87,6 @@ import java.nio.file.attribute.FileTime;
 import java.nio.file.attribute.PosixFilePermission;
 import java.nio.file.attribute.PosixFilePermissions;
 import java.nio.file.attribute.UserPrincipal;
-import java.util.Arrays;
 import java.util.Iterator;
 import java.util.Set;
 import java.util.regex.PatternSyntaxException;
@@ -188,8 +187,7 @@ public class JimfsUnixLikeFileSystemTest extends AbstractJimfsIntegrationTest {
     Path p3 = path("c");
     Path p4 = path("D");
 
-    assertThat(Ordering.natural().immutableSortedCopy(Arrays.asList(p3, p4, p1, p2)))
-        .isEqualTo(ImmutableList.of(p2, p4, p1, p3));
+    assertThat(ImmutableSortedSet.of(p3, p4, p1, p2)).containsExactly(p2, p4, p1, p3).inOrder();
 
     // would be p1, p2, p3, p4 if sorting were case insensitive
   }
