@@ -27,10 +27,6 @@ import com.google.common.collect.FluentIterable;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableSet;
 import com.google.common.collect.Sets;
-
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 import java.io.IOException;
 import java.lang.reflect.Method;
 import java.lang.reflect.Modifier;
@@ -40,6 +36,8 @@ import java.util.EnumSet;
 import java.util.List;
 import java.util.Random;
 import java.util.Set;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
 
 /**
  * Tests for {@link RegularFile} and by extension for {@link HeapDisk}. These tests test files
@@ -100,40 +98,31 @@ public class RegularFileTest {
           .toList();
 
   /**
-   * Different strategies for handling reuse of disks and/or files between tests, intended to
-   * ensure that {@link HeapDisk} operates properly in a variety of usage states including newly
-   * created, having created files that have not been deleted yet, having created files that have
-   * been deleted, and having created files some of which have been deleted and some of which have
-   * not.
+   * Different strategies for handling reuse of disks and/or files between tests, intended to ensure
+   * that {@link HeapDisk} operates properly in a variety of usage states including newly created,
+   * having created files that have not been deleted yet, having created files that have been
+   * deleted, and having created files some of which have been deleted and some of which have not.
    */
   public enum ReuseStrategy {
-    /**
-     * Creates a new disk for each test.
-     */
+    /** Creates a new disk for each test. */
     NEW_DISK,
-    /**
-     * Retains files after each test, forcing new blocks to be allocated.
-     */
+    /** Retains files after each test, forcing new blocks to be allocated. */
     KEEP_FILES,
-    /**
-     * Deletes files after each test, allowing caching to be used if enabled.
-     */
+    /** Deletes files after each test, allowing caching to be used if enabled. */
     DELETE_FILES,
-    /**
-     * Randomly keeps or deletes a file after each test.
-     */
+    /** Randomly keeps or deletes a file after each test. */
     KEEP_OR_DELETE_FILES
   }
 
-  /**
-   * Configuration for a set of test cases.
-   */
+  /** Configuration for a set of test cases. */
   public static final class TestConfiguration {
 
     private final int blockSize;
     private final int cacheSize;
     private final ReuseStrategy reuseStrategy;
 
+    private final FakeFileTimeSource fileTimeSource = new FakeFileTimeSource();
+
     private HeapDisk disk;
 
     public TestConfiguration(int blockSize, int cacheSize, ReuseStrategy reuseStrategy) {
@@ -155,7 +144,7 @@ public class RegularFileTest {
       if (reuseStrategy == ReuseStrategy.NEW_DISK) {
         disk = createDisk();
       }
-      return RegularFile.create(0, disk);
+      return RegularFile.create(0, fileTimeSource.now(), disk);
     }
 
     public void tearDown(RegularFile file) {
@@ -181,12 +170,11 @@ public class RegularFileTest {
     }
   }
 
-  /**
-   * Actual test cases for testing RegularFiles.
-   */
+  /** Actual test cases for testing RegularFiles. */
   public static class RegularFileTestRunner extends TestCase {
 
     private final TestConfiguration configuration;
+    private final FakeFileTimeSource fileTimeSource = new FakeFileTimeSource();
 
     protected RegularFile file;
 
@@ -349,23 +337,31 @@ public class RegularFileTest {
       assertContentEquals("111111", file);
     }
 
-    public void testEmpty_transferFrom_fromBeyondStart_countEqualsSrcSize() throws IOException {
+    public void testEmpty_transferFrom_positionGreaterThanSize() throws IOException {
       long transferred = file.transferFrom(new ByteBufferChannel(buffer("111111")), 4, 6);
-      assertEquals(6, transferred);
-      assertContentEquals("0000111111", file);
+      assertEquals(0, transferred);
+      assertContentEquals(bytes(), file);
     }
 
-    public void testEmpty_transferFrom_fromBeyondStart_countLessThanSrcSize() throws IOException {
+    public void testEmpty_transferFrom_positionGreaterThanSize_countEqualsSrcSize()
+        throws IOException {
+      long transferred = file.transferFrom(new ByteBufferChannel(buffer("111111")), 4, 6);
+      assertEquals(0, transferred);
+      assertContentEquals(bytes(), file);
+    }
+
+    public void testEmpty_transferFrom_positionGreaterThanSize_countLessThanSrcSize()
+        throws IOException {
       long transferred = file.transferFrom(new ByteBufferChannel(buffer("111111")), 4, 3);
-      assertEquals(3, transferred);
-      assertContentEquals("0000111", file);
+      assertEquals(0, transferred);
+      assertContentEquals(bytes(), file);
     }
 
-    public void testEmpty_transferFrom_fromBeyondStart_countGreaterThanSrcSize()
+    public void testEmpty_transferFrom_positionGreaterThanSize_countGreaterThanSrcSize()
         throws IOException {
       long transferred = file.transferFrom(new ByteBufferChannel(buffer("111111")), 4, 12);
-      assertEquals(6, transferred);
-      assertContentEquals("0000111111", file);
+      assertEquals(0, transferred);
+      assertContentEquals(bytes(), file);
     }
 
     public void testEmpty_transferFrom_fromStart_noBytes_countEqualsSrcSize() throws IOException {
@@ -381,18 +377,18 @@ public class RegularFileTest {
       assertContentEquals(bytes(), file);
     }
 
-    public void testEmpty_transferFrom_fromBeyondStart_noBytes_countEqualsSrcSize()
+    public void testEmpty_transferFrom_postionGreaterThanSrcSize_noBytes_countEqualsSrcSize()
         throws IOException {
       long transferred = file.transferFrom(new ByteBufferChannel(buffer("")), 5, 0);
       assertEquals(0, transferred);
-      assertContentEquals(bytes("00000"), file);
+      assertContentEquals(bytes(), file);
     }
 
-    public void testEmpty_transferFrom_fromBeyondStart_noBytes_countGreaterThanSrcSize()
+    public void testEmpty_transferFrom_postionGreaterThanSrcSize_noBytes_countGreaterThanSrcSize()
         throws IOException {
       long transferred = file.transferFrom(new ByteBufferChannel(buffer("")), 5, 10);
       assertEquals(0, transferred);
-      assertContentEquals(bytes("00000"), file);
+      assertContentEquals(bytes(), file);
     }
 
     public void testEmpty_transferTo() throws IOException {
@@ -401,7 +397,7 @@ public class RegularFileTest {
     }
 
     public void testEmpty_copy() throws IOException {
-      RegularFile copy = file.copyWithoutContent(1);
+      RegularFile copy = file.copyWithoutContent(1, fileTimeSource.now());
       assertContentEquals("", copy);
     }
 
@@ -580,7 +576,7 @@ public class RegularFileTest {
     public void testNonEmpty_read_fromPastEnd_singleBuffer() throws IOException {
       fillContent("123");
       ByteBuffer buffer = ByteBuffer.allocate(3);
-      file.read(3, buffer);
+      assertEquals(-1, file.read(3, buffer));
       assertBufferEquals("000", 3, buffer);
     }
 
@@ -808,11 +804,11 @@ public class RegularFileTest {
       assertContentEquals("222222111111", file);
     }
 
-    public void testNonEmpty_transferFrom_toPastEnd() throws IOException {
+    public void testNonEmpty_transferFrom_positionGreaterThanSize() throws IOException {
       fillContent("222222");
       ByteBufferChannel channel = new ByteBufferChannel(buffer("111111"));
-      assertEquals(6, file.transferFrom(channel, 10, 6));
-      assertContentEquals("2222220000111111", file);
+      assertEquals(0, file.transferFrom(channel, 10, 6));
+      assertContentEquals("222222", file);
     }
 
     public void testNonEmpty_transferFrom_hugeOverestimateCount() throws IOException {
@@ -824,16 +820,16 @@ public class RegularFileTest {
 
     public void testNonEmpty_copy() throws IOException {
       fillContent("123456");
-      RegularFile copy = file.copyWithoutContent(1);
+      RegularFile copy = file.copyWithoutContent(1, fileTimeSource.now());
       file.copyContentTo(copy);
       assertContentEquals("123456", copy);
     }
 
     public void testNonEmpty_copy_multipleTimes() throws IOException {
       fillContent("123456");
-      RegularFile copy = file.copyWithoutContent(1);
+      RegularFile copy = file.copyWithoutContent(1, fileTimeSource.now());
       file.copyContentTo(copy);
-      RegularFile copy2 = copy.copyWithoutContent(2);
+      RegularFile copy2 = copy.copyWithoutContent(2, fileTimeSource.now());
       copy.copyContentTo(copy2);
       assertContentEquals("123456", copy);
     }
@@ -900,7 +896,7 @@ public class RegularFileTest {
     protected static void assertContentEquals(byte[] expected, RegularFile actual) {
       assertEquals(expected.length, actual.sizeWithoutLocking());
       byte[] actualBytes = new byte[(int) actual.sizeWithoutLocking()];
-      actual.read(0, ByteBuffer.wrap(actualBytes));
+      int unused = actual.read(0, ByteBuffer.wrap(actualBytes));
       assertArrayEquals(expected, actualBytes);
     }
   }
